==> claromentis-framework-8.13.65-b8aa1bfb.zip: web/intranet/admin/classes/Sysadmin/Ldap/Action/Connect.php <==
<?php
namespace Claromentis\Admin\Sysadmin\Ldap\Action;

$GLOBALS["__65da1b1ec2d6653e8a0a" . "b7848e536215"] = (@$GLOBALS["__65da1b1ec" . "2d6653e8a0a" . "b7848e53621" . "5"] ?: array()) + array("_e34c88c96a06b" . "f0253b10a9806e" . "d1bbf" => base64_decode("YWRtaW4ubGRhcC5lcnJvci5j" . "YW50X3JlYWRfYmFzZV9kbg=="), "_0c5123aa744f69bbc0e8b3ea2f" . "6e847d" => base64_decode("bG1z" . "Zw=="));
use Claromentis\Admin\Sysadmin\Ldap\Action;
use Claromentis\Admin\Sysadmin\Ldap\ConnectionInfo;
use Claromentis\Admin\Sysadmin\Ldap\Exception\ActionException;
use Claromentis\Core\User\Directory\Exception\LdapException;








class Connect implements Action
{
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function Run(ConnectionInfo $_12e791699eac68001ce474ba4b8c1031, array $data)
    {
        try {
            $_360c647d4c765175a91a97e78e9f9558 = $_12e791699eac68001ce474ba4b8c1031->GetConnection();
            $_360c647d4c765175a91a97e78e9f9558->Connect();
            $_0d554e76e5204294feffa4dddea981e2 = $_360c647d4c765175a91a97e78e9f9558->Read($_12e791699eac68001ce474ba4b8c1031->GetSettings()->base_dn);
            if (!$_0d554e76e5204294feffa4dddea981e2) {
                throw new ActionException($GLOBALS["__65da1b1ec2d665" . "3e8a0ab7848e5362" . "15"]["_0c5123aa744f69bbc0e8" . "b3ea2f6e847d"]($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_e34c88c96a06" . "bf0253b10a980" . "6ed1bbf"]));
            }
        } catch (LdapException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
            throw new ActionException($_fe441aa3ef350bfb1a1a1ad8520dd530->getMessage());
        }
        return [];
    }
}

==> claromentis-framework-9.6.5-177028fb.zip: web/intranet/admin/classes/Sysadmin/Ldap/Action/Connect.php <==
<?php
namespace Claromentis\Admin\Sysadmin\Ldap\Action;

$GLOBALS["__65da1b1ec2d6653e8a0ab78" . "48e536215"] = (@$GLOBALS["__65da1b1ec2d6653e8a0ab7848e53" . "6215"] ?: array()) + array("_e34c88c96a06bf025" . "3b10a9806ed1bbf" => base64_decode("YWRtaW4ubGRhcC5lcnJvci5jYW50X3JlY" . "WRfYmFzZV9kbg=="), "_0c5123aa744f69bbc0e8b3ea2f6" . "e847d" => base64_decode("bG1" . "zZw" . "=="));
use Claromentis\Admin\Sysadmin\Ldap\Action;
use Claromentis\Admin\Sysadmin\Ldap\ConnectionInfo;
use Claromentis\Admin\Sysadmin\Ldap\Exception\ActionException;
use Claromentis\Core\User\Directory\Exception\LdapException;








class Connect implements Action
{
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    
    public function Run(ConnectionInfo $_12e791699eac68001ce474ba4b8c1031, array $data)
    {
        try {
            $_360c647d4c765175a91a97e78e9f9558 = $_12e791699eac68001ce474ba4b8c1031->GetConnection();
            $_360c647d4c765175a91a97e78e9f9558->Connect();
            $_0d554e76e5204294feffa4dddea981e2 = $_360c647d4c765175a91a97e78e9f9558->Read($_12e791699eac68001ce474ba4b8c1031->GetSettings()->base_dn);
            if (!$_0d554e76e5204294feffa4dddea981e2) {
                throw new ActionException($GLOBALS["__65da1b1ec2d6653e8a0ab" . "7848e536215"]["_0c5123aa744f69bbc0e8b3ea" . "2f6e847d"]($GLOBALS["__65da1b1ec2d6653e8a" . "0ab7848e536215"]["_e34c88c96" . "a06bf0253b" . "10a9806ed1" . "bbf"]));
            }
        } catch (LdapException $_fe441aa3ef350bfb1a1a1ad8520dd530) {
            throw new ActionException($_fe441aa3ef350bfb1a1a1ad8520dd530->getMessage());
        }
        return [];
    }
}
